@@ -1,15 +1,18 @@
-#!/21Q1/bin/python3.8
+#!/usr/pkg/bin/python3.12
 """List all colors used in an svg document"""
 
 from collections import defaultdict
+from typing import Dict
 import inkex
 
+
 class ListColours(inkex.ColorExtension):
     """Make the colours darker"""
-    _counts = defaultdict(int)
+
+    _counts: Dict = defaultdict(int)
 
     def effect(self):
-        super(ListColours, self).effect()
+        super().effect()
         items = sorted(self._counts.items(), key=lambda v: -v[1])
         for color, count in items:
             self.msg("{count}: {color}".format(color=color, count=count))
@@ -18,5 +21,6 @@ class ListColours(inkex.ColorExtension):
         self._counts[color] += 1
         return color
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     ListColours().run()
