@@ -1,4 +1,4 @@
-#!/21Q1/bin/python3.8
+#!/usr/pkg/bin/python3.12
 # coding=utf-8
 #
 # Copyright (C) 2020 Martin Owens <doctormo@gmail.com>
@@ -22,14 +22,17 @@ Path To Absolute
 """
 import inkex
 
+
 class ToAbsolute(inkex.EffectExtension):
     """Convert any selected object to absolute/object-to-path/bezier only paths"""
+
     def effect(self):
         """Performs the effect."""
-        for node in self.svg.selected.values():
+        for node in self.svg.selection.values():
             if not isinstance(node, inkex.PathElement):
                 node = node.replace_with(node.to_path_element())
             node.path = node.path.to_absolute().to_superpath().to_path()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     ToAbsolute().run()
